Struct Lioness
pub struct Lioness<H, S, B>where
H: KeySizeUser + OutputSizeUser,
S: KeySizeUser + IvSizeUser,
B: ArrayLength<u8> + IsGreater<<S as KeySizeUser>::KeySize, Output = B1>,
<H as OutputSizeUser>::OutputSize: IsEqual<<S as KeySizeUser>::KeySize, Output = B1>,
<H as KeySizeUser>::KeySize: IsEqual<<S as KeySizeUser>::KeySize, Output = B1>,{
k1: GenericArray<u8, <S as KeySizeUser>::KeySize>,
k2: GenericArray<u8, <H as KeySizeUser>::KeySize>,
k3: GenericArray<u8, <S as KeySizeUser>::KeySize>,
k4: GenericArray<u8, <H as KeySizeUser>::KeySize>,
iv1: GenericArray<u8, <S as IvSizeUser>::IvSize>,
iv2: GenericArray<u8, <S as IvSizeUser>::IvSize>,
_phantom: PhantomData<(H, S, B)>,
}Expand description
Implementation of Lioness wide-block cipher over a keyed Digest and a StreamCipher.
Requirements
- The output size of the
DigestHmust match the key size of theStreamCipher. - The key size of the keyed digest
Hmust be equal to the key size of theStreamCipher. - The block size
Bcan be arbitrary but must be strictly greater than the key size of theStreamCipher. - However, for cryptographic security,
Bmust be at least twice the key size of theStreamCipher.
The key size of the Lioness cipher is 4-times the size of StreamCipher’s
key.
The IV size of the Lioness cipher is 2-times the size of the StreamCipher’s
IV size.
Fields
k1: GenericArray<u8, <S as KeySizeUser>::KeySize>k2: GenericArray<u8, <H as KeySizeUser>::KeySize>k3: GenericArray<u8, <S as KeySizeUser>::KeySize>k4: GenericArray<u8, <H as KeySizeUser>::KeySize>iv1: GenericArray<u8, <S as IvSizeUser>::IvSize>iv2: GenericArray<u8, <S as IvSizeUser>::IvSize>_phantom: PhantomData<(H, S, B)>Implementations
impl<H, S, B> Lioness<H, S, B>where
H: Digest + KeyInit,
S: StreamCipher + KeyIvInit,
B: ArrayLength<u8> + IsGreater<<S as KeySizeUser>::KeySize, Output = B1> + Sub<<S as KeySizeUser>::KeySize>,
<H as OutputSizeUser>::OutputSize: IsEqual<<S as KeySizeUser>::KeySize, Output = B1> + Mul<UInt<UInt<UInt<UTerm, B1>, B0>, B0>>,
<H as KeySizeUser>::KeySize: IsEqual<<S as KeySizeUser>::KeySize, Output = B1>,
<B as Sub<<S as KeySizeUser>::KeySize>>::Output: ArrayLength<u8>,
<S as IvSizeUser>::IvSize: Mul<UInt<UInt<UTerm, B1>, B0>>,
<<H as OutputSizeUser>::OutputSize as Mul<UInt<UInt<UInt<UTerm, B1>, B0>, B0>>>::Output: ArrayLength<u8>,
<<S as IvSizeUser>::IvSize as Mul<UInt<UInt<UTerm, B1>, B0>>>::Output: ArrayLength<u8>,
impl<H, S, B> Lioness<H, S, B>where
H: Digest + KeyInit,
S: StreamCipher + KeyIvInit,
B: ArrayLength<u8> + IsGreater<<S as KeySizeUser>::KeySize, Output = B1> + Sub<<S as KeySizeUser>::KeySize>,
<H as OutputSizeUser>::OutputSize: IsEqual<<S as KeySizeUser>::KeySize, Output = B1> + Mul<UInt<UInt<UInt<UTerm, B1>, B0>, B0>>,
<H as KeySizeUser>::KeySize: IsEqual<<S as KeySizeUser>::KeySize, Output = B1>,
<B as Sub<<S as KeySizeUser>::KeySize>>::Output: ArrayLength<u8>,
<S as IvSizeUser>::IvSize: Mul<UInt<UInt<UTerm, B1>, B0>>,
<<H as OutputSizeUser>::OutputSize as Mul<UInt<UInt<UInt<UTerm, B1>, B0>, B0>>>::Output: ArrayLength<u8>,
<<S as IvSizeUser>::IvSize as Mul<UInt<UInt<UTerm, B1>, B0>>>::Output: ArrayLength<u8>,
pub fn encrypt_block(
&self,
block: InOut<'_, '_, GenericArray<u8, <Lioness<H, S, B> as BlockSizeUser>::BlockSize>>,
)
pub fn encrypt_block( &self, block: InOut<'_, '_, GenericArray<u8, <Lioness<H, S, B> as BlockSizeUser>::BlockSize>>, )
Performs encryption of the given block.
pub fn decrypt_block(
&self,
block: InOut<'_, '_, GenericArray<u8, <Lioness<H, S, B> as BlockSizeUser>::BlockSize>>,
)
pub fn decrypt_block( &self, block: InOut<'_, '_, GenericArray<u8, <Lioness<H, S, B> as BlockSizeUser>::BlockSize>>, )
Performs decryption of the given block.