Enum ExtmarkVirtTextPosition
#[non_exhaustive]pub enum ExtmarkVirtTextPosition {
Eol,
Overlay,
RightAlign,
Inline,
}Expand description
Controls the positioning of the virtual text associated to an extmark.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Eol
Right after the EOL character (default).
Overlay
Display over the specified column, without shifting the underlying text.
RightAlign
Display right aligned in the window.
Inline
Display at the specified column, and shift the buffer text to the right as needed.