Enum WindowRelativeTo
#[non_exhaustive]pub enum WindowRelativeTo {
Editor,
Cursor,
Mouse,
Window(Window),
}Expand description
Specifies what a floating window is positioned relative to.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Editor
Positions the window relative to the global Neovim editor grid.
Cursor
Positions the window relative to the current cursor position.
Mouse
Positions the window relative to the current mouse cursor position..
Window(Window)
Positions the window relative to another window.