Struct WinTextHeightInfos
pub struct WinTextHeightInfos {
pub all: u32,
pub fill: u32,
}Expand description
Infos returned by Window::text_height().
Fields
all: u32The total number of screen lines occupied by the range.
fill: u32The number of diff filler or virtual lines among them.