Crate pzzld_server

puzzled

puzzled is a library for creating and managing a network of nodes.

Re-exports

pub use super::BoxError;
pub use super::BoxResult;
pub use super::Result;
pub use super::action::*;
pub use super::conduit::*;
pub use super::handle::*;
pub use super::stateful::*;
pub use super::platform::*;
pub use super::power::*;
pub use super::stage::*;
pub use super::timestamp::*;

Modules

cli
config
Configuration
consts
error
platform
Context (ctx)
prelude
traits
types
types
workers

Structs

Context
Platform
Settings

Enums

Error

Constants

APP_NAME
The name of the application.
ARTIFACTS
The name of the artifacts directory.
DEFAULT_CONFIG_DIR
The default location for the configuration directory.
DEFAULT_CONTEXT
DEFAULT_HOST
DEFAULT_PORT
The default port for the application.
DEFAULT_WORKDIR
LOCALHOST
A str constant for the localhost address.

Functions

graceful_shutdown
std_time
systime
systime is a utilitarian function that returns the current system time in milliseconds.
timestamp