Crate ic_websocket_cdk
source ·Re-exports
pub use types::CanisterWsSendResult;Deprecatedpub use types::CanisterCloseResult;pub use types::CanisterSendResult;pub use types::CanisterWsCloseArguments;pub use types::CanisterWsCloseResult;pub use types::CanisterWsGetMessagesArguments;pub use types::CanisterWsGetMessagesResult;pub use types::CanisterWsMessageArguments;pub use types::CanisterWsMessageResult;pub use types::CanisterWsOpenArguments;pub use types::CanisterWsOpenResult;pub use types::ClientPrincipal;pub use types::OnCloseCallbackArgs;pub use types::OnMessageCallbackArgs;pub use types::OnOpenCallbackArgs;pub use types::WsHandlers;pub use types::WsInitParams;
Modules
Macros
Functions
- Closes the connection with the client.
- Initialize the CDK.
- Sends a message to the client. The message must already be serialized using Candid. Use candid::encode_one to serialize the message.
- Resets the internal state of the IC WebSocket CDK.
- Handles the WS connection close event received from the WS Gateway.
- Returns messages to the WS Gateway in response of a polling iteration.
- Handles the WS messages received either directly from the client or relayed by the WS Gateway.
- Handles the WS connection open event sent by the client and relayed by the Gateway.
- ws_sendDeprecatedDeprecated: use send instead.