Crate agentrs_core

Crate agentrs_core 

Foundational traits and shared types for the agentrs SDK.

Re-exports

pub use error::AgentError;
pub use error::BoxError;
pub use error::McpError;
pub use error::MemoryError;
pub use error::ProviderError;
pub use error::Result;
pub use error::ToolError;
pub use types::AgentEvent;
pub use types::AgentOutput;
pub use types::CompletionRequest;
pub use types::CompletionResponse;
pub use types::ContentPart;
pub use types::Message;
pub use types::MessageContent;
pub use types::Role;
pub use types::StopReason;
pub use types::StreamChunk;
pub use types::ToolCall;
pub use types::ToolCallDelta;
pub use types::ToolContent;
pub use types::ToolDefinition;
pub use types::ToolOutput;
pub use types::Usage;

Modules

error
Shared SDK error types.
streaming
Streaming helpers.
testing
Test utilities for SDK users and internal crates.
types
Shared types used across providers, tools, memory, and agents.

Traits

Agent
Contract for executable agents.
LlmProvider
Unified contract for chat-completion capable LLM providers.
Memory
Contract for agent memory backends.
Tool
Unified contract for agent tools.