Pure Rust implementation of complex Bessel functions based on Amos Algorithm 644 (TOMS 644).
This crate provides complex-valued Bessel functions of the first kind (J), second kind (Y), modified first kind (I), modified second kind (K), Hankel functions (H), and Airy functions (Ai, Bi).
Status
This crate is in early development (alpha). Function signatures are defined but implementations are not yet available.
Re-exports
pub use machine::BesselFloat;pub use types::AiryDerivative;pub use types::BesselError;pub use types::BesselResult;pub use types::HankelKind;pub use types::Scaling;
Modules
Functions
- airy
- Airy function Ai(z) or its derivative Ai’(z).
- besseli
- Modified Bessel function of the first kind, I_ν(z).
- besseli_
seq - Compute I_{ν+j}(z) for j = 0, 1, …, n-1.
- besselj
- Bessel function of the first kind, J_ν(z).
- besselj_
seq - Compute J_{ν+j}(z) for j = 0, 1, …, n-1.
- besselk
- Modified Bessel function of the second kind, K_ν(z).
- besselk_
seq - Compute K_{ν+j}(z) for j = 0, 1, …, n-1.
- bessely
- Bessel function of the second kind, Y_ν(z).
- bessely_
seq - Compute Y_{ν+j}(z) for j = 0, 1, …, n-1.
- biry
- Airy function Bi(z) or its derivative Bi’(z).
- hankel
- Hankel function, H_ν^(m)(z).
- hankel_
seq - Compute H_{ν+j}^(m)(z) for j = 0, 1, …, n-1.